@@ -291,13 +291,13 @@ class IotToSqsProps:
         :summary: The properties for the IotToSqs class.
         '''
         if isinstance(iot_topic_rule_props, dict):
-            iot_topic_rule_props = CfnTopicRuleProps(**iot_topic_rule_props)
+            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
         if isinstance(dead_letter_queue_props, dict):
-            dead_letter_queue_props = QueueProps(**dead_letter_queue_props)
+            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
         if isinstance(encryption_key_props, dict):
-            encryption_key_props = KeyProps(**encryption_key_props)
+            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
         if isinstance(queue_props, dict):
-            queue_props = QueueProps(**queue_props)
+            queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
         if __debug__:
             type_hints = typing.get_type_hints(IotToSqsProps.__init__)
             check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
